@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0300';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -43,6 +43,25 @@ sub _build__scale {
     return \@with_octaves;
 }
 
+has _enharmonics => (
+    is        => 'lazy',
+    init_args => undef,
+);
+
+sub _build__enharmonics {
+  my ($self) = @_;
+  my %enharmonics = (
+      'C#' => 'Db',
+      'D#' => 'Eb',
+      'E#' => 'F',
+      'F#' => 'Gb',
+      'G#' => 'Ab',
+      'A#' => 'Bb',
+      'B#' => 'C',
+  );
+  return { %enharmonics, reverse %enharmonics }
+}
+
 
 has verbose => (
     is      => 'ro',
@@ -57,7 +76,8 @@ sub intervals {
     my @pitches;
 
     for my $note (@$notes) {
-        push @pitches, first_index { $_ eq $note } @{ $self->_scale };
+        (my $i, $note) = $self->_find_pitch($note);
+        push @pitches, $i;
     }
     print 'Pitches: ', ddc(\@pitches) if $self->verbose;
 
@@ -85,7 +105,8 @@ sub invert {
 
     for my $interval (@$intervals) {
         # Find the note that is the opposite interval away from the original note
-        my $pitch = $self->_scale->[ (first_index { $_ eq $note } @{ $self->_scale }) - $interval ];
+        (my $i, $note) = $self->_find_pitch($note);
+        my $pitch = $self->_scale->[ $i - $interval ];
 
         push @inverted, $pitch;
 
@@ -97,6 +118,17 @@ sub invert {
     return \@inverted;
 }
 
+sub _find_pitch {
+    my ($self, $pitch) = @_;
+    my $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    if ($i == -1) {
+        my $enharmonics = $self->_enharmonics;
+        $pitch =~ s/^([A-G][#b]?)(\d+)$/$enharmonics->{$1}$2/;
+        $i = first_index { $_ eq $pitch } @{ $self->_scale };
+    }
+    return $i, $pitch;
+}
+
 1;
 
 __END__
@@ -111,7 +143,7 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0200
+version 0.0300
 
 =head1 SYNOPSIS
 
